options compress=YES;
libname data ''; 
libname output ''; 
libname earn '';
libname sdr '';

* CREATE VARIABLES FROM ANNUAL 831 FILES ;
* INPUT: ANNUAL 831 FILES PROVIDED BY SSA OFFICE OF RESEARCH, EVALUATION, AND STATISTICS
	(located in folder ../offices/data/originals);

%macro new(year);
data data.tab_f831_cy&year.;
	set data.f831_cy&year.;

	/* Missing values */
	if zip='' or zip='000000000' then zip_miss=1; else zip_miss=0;
	if do='' or do='ZZZ' then do_miss=1; else do_miss=0;
	if mln='' or mln='ZZZZZZZ' then mln_miss=1; else mln_miss=0;
	if spc='' or spc='99' then spc_miss=1; else spc_miss=0;

	/* Benefiary ID */
	if bic='A' then bic_prim=1; else bic_prim=0;

	/* Adjudicative level */
	if al='A' then al_init=1; else al_init=0;
	if al='B' or al='C' then al_recon=1; else al_recon=0;
	if al='D' then al_alj=1; else al_alj=0;
	if al='E' or al='F' or al='G' or al='I' or al='Z' then al_other=1; else al_other=0;

	/* Type of claim */
	toc_all=1;
	if rid='R' then toc_ssi=1; else toc_ssi=0;
	if toc='1' or toc='2' then toc_diadult=1; else toc_diadult=0;
	if toc='A' or toc='D' then toc_ssiadult=1; else toc_ssiadult=0;
	if toc_diadult=1 or toc_ssiadult=1 then toc_adult=1; else toc_adult=0;
	if toc='C' or toc='F' then toc_ssikid=1; else toc_ssikid=0;
	if ccf='Y' then toc_concur=1; else toc_concur=0;

	/* Allowed at given level */
	if al='A' & rdt='A' then allow_init=1; else allow_init=0;
	if al='B' & rdt='A' then allow_recon=1; else allow_recon=0;
	if rdt='A' then allow_dds=1; else allow_dds=0;

	/* Age at filing */
	if fld_yy=9999 or fld_yy<1900 then fld_yy=.;
	if fld_mm=99 then fld_mm=.;
	if fld_dd=99 then fld_dd=.;
	if fld_dd=88 then fld_dd=.;
	if fld_mm=88 then fld_mm=.;
	if dob_yy=9999 or dob_yy<1900 then dob_yy=.;
	if dob_mm=99 then dob_mm=.;
	if dob_dd=99 then dob_dd=.;
	if dob_mm=88 then dob_mm=.;
	if dob_dd=88 then dob_dd=.;
	if dob_yy=1925 & dob_mm=2 & dob_dd=29 then dob_dd=28;
	if dob_yy=1927 & dob_mm=2 & dob_dd=29 then dob_dd=28;
	if dob_yy=1929 & dob_mm=2 & dob_dd=29 then dob_dd=28;
	if dob_yy=1930 & dob_mm=2 & dob_dd=29 then dob_dd=28;
	if dob_yy=1930 & dob_mm=2 & dob_dd=30 then dob_dd=28;
	if dob_yy=1931 & dob_mm=2 & dob_dd=29 then dob_dd=28;
	if dob_yy=1933 & dob_mm=2 & dob_dd=29 then dob_dd=28;
	if dob_yy=1934 & dob_mm=2 & dob_dd=29 then dob_dd=28;
	if dob_yy=1934 & dob_mm=2 & dob_dd=30 then dob_dd=28;
	if dob_yy=1935 & dob_mm=2 & dob_dd=29 then dob_dd=28;
	if dob_yy=1937 & dob_mm=2 & dob_dd=29 then dob_dd=28;
	if dob_yy=1937 & dob_mm=2 & dob_dd=30 then dob_dd=28;
	if dob_yy=1937 & dob_mm=2 & dob_dd=31 then dob_dd=28;
	if dob_yy=1938 & dob_mm=2 & dob_dd=29 then dob_dd=28;
	if dob_yy=1938 & dob_mm=2 & dob_dd=31 then dob_dd=28;
	if dob_yy=1939 & dob_mm=2 & dob_dd=29 then dob_dd=28;
	if dob_yy=1940 & dob_mm=2 & dob_dd=30 then dob_dd=28;
	if dob_yy=1942 & dob_mm=2 & dob_dd=29 then dob_dd=28;
	if dob_yy=1943 & dob_mm=2 & dob_dd=29 then dob_dd=28;
	if dob_yy=1943 & dob_mm=2 & dob_dd=31 then dob_dd=28;
	if dob_yy=1944 & dob_mm=2 & dob_dd=31 then dob_dd=28;
	if dob_yy=1946 & dob_mm=2 & dob_dd=29 then dob_dd=28;
	if dob_yy=1950 & dob_mm=2 & dob_dd=29 then dob_dd=28;
	if dob_yy=1953 & dob_mm=2 & dob_dd=29 then dob_dd=28;
	if dob_yy=1953 & dob_mm=2 & dob_dd=31 then dob_dd=28;
	if dob_yy=1954 & dob_mm=2 & dob_dd=29 then dob_dd=28;
	if dob_yy=1954 & dob_mm=2 & dob_dd=30 then dob_dd=28;
	if dob_yy=1958 & dob_mm=2 & dob_dd=29 then dob_dd=28;
	if dob_yy=1959 & dob_mm=2 & dob_dd=29 then dob_dd=28;
	if dob_mm=11 & dob_dd=31 then dob_dd=30;
	if dob_mm=9 & dob_dd=31 then dob_dd=30;
	if dob_mm=6 & dob_dd=31 then dob_dd=30;
	if dob_mm=4 & dob_dd=31 then dob_dd=30;
	fld_sas=mdy(fld_mm,fld_dd,fld_yy);
	dob_sas=mdy(dob_mm,dob_dd,dob_yy);
	n_age=(fld_sas-dob_sas)/365;
	if n_age>=0 & n_age<10 	then age_0to9=1;  else age_0to9=0;
	if n_age>=10 & n_age<18 then age_10to17=1; else age_10to17=0;
	if n_age>=18 & n_age<35 then age_18to34=1; else age_18to34=0;
	if n_age>=35 & n_age<50 then age_35to49=1; else age_35to49=0;
	if n_age>=50 			then age_50plus=1; else age_50plus=0;

	/* Age over or under 62 */
	if n_age>=62 then age_62plus=1; else age_62plus=0;
	if n_age<62 & n_age>=55 then age_55to61=1; else age_55to61=0;

	/* Body code */
	if toc_ssikid=0 & bs='12' then bs_mental=1; 
		else if toc_ssikid=1 & bs='12' then bs_mental=1; 
		else bs_mental=0;
	if toc_ssikid=0 & bs='01' then bs_musc=1; 
		else bs_musc=0;
	if toc_ssikid=0 & bs^='12' & bs^='01' then bs_phys=1; 
		else if toc_ssikid=1 & bs^='12' then bs_phys=1; 
		else bs_phys=0;
	
	/* Education */
	if ed='99' or ed="'" or ed='ZZ' or ed='1:' or ed='2!' or ed='?' then ed='';
	n_ed = input(ed,2.0);
	if toc='C' or toc='F' then n_ed=.;
	if n_ed<12 then ed_hsdrop=1; else ed_hsdrop=0;
	if n_ed>=12 & n_ed<16 then ed_hsgrad=1; else ed_hsgrad=0;
	if n_ed>=16 then ed_collgrad=1; else ed_collgrad=0;

	if n_ed=. then do;
		ed_hsdrop=.;
		ed_hsgrad=.;
		ed_collgrad=.;
	end;

	/* Permanent */
	if dpm='0' or dpm='' then dpm_den=1; else dpm_den=0;
	if dpm='N' then dpm_notperm=1; else dpm_notperm=0;
	if dpm='P' then dpm_perm=1; else dpm_perm=0;

	/* Diary */
	if dr='' then dr_den=1; else dr_den=0;
	if dr='3' then dr_mip=1; 
		else if 
			(
				(dr='E' or dr='F' or dr='G' or dr='I' or dr='J' or dr='K' or dr='L'
			 	or  dr='M' or dr='N' or dr='V' or dr='W' or dr='X' or dr='Y' or dr='Z')
			 	& dpm^='P'
			)
			then dr_mip=1;
		else dr_mip=0;
	if (dr='5' or dr='7') then dr_mine=1; 
		else if 
			(
				(dr='E' or dr='F' or dr='G' or dr='I' or dr='J' or dr='K' or dr='L'
			 	or  dr='M' or dr='N' or dr='V' or dr='W' or dr='X' or dr='Y' or dr='Z')
			 	& dpm='P'
			)
			then dr_mine=1;
		else dr_mine=0;
	if (dr='A' or dr='B' or dr='C' or dr='D' or dr='H' or dr='O' or dr='P'
		or  dr='Q' or dr='R' or dr='S' or dr='T' or dr='U')
		then dr_mie=1;
		else dr_mie=0;

	if dr_den=1 then sev_den=1; else sev_den=0;
	if dr_mie=1 or dr_mip=1 then sev_high=1; else sev_high=0;
	if dr_mine=1 then sev_vh=1; else sev_vh=0;

	/* Education x disability type groups */
	if bs_mental=1 and ed_hsdrop=1 then edbs_dropment=1; else edbs_dropment=0;
	if bs_mental=1 and ed_hsgrad=1 then edbs_hsment=1; else edbs_hsment=0;
	if bs_mental=1 and ed_collgrad=1 then edbs_collment=1; else edbs_collment=0;
	if bs_phys=1 and ed_hsdrop=1 then edbs_dropphys=1; else edbs_dropphys=0;
	if bs_phys=1 and ed_hsgrad=1 then edbs_hsphys=1; else edbs_hsphys=0;
	if bs_phys=1 and ed_collgrad=1 then edbs_collphys=1; else edbs_collphys=0;
	if bs_musc=1 and ed_hsdrop=1 then edbs_dropmusc=1; else edbs_dropmusc=0;
	if bs_musc=1 and ed_hsgrad=1 then edbs_hsmusc=1; else edbs_hsmusc=0;
	if bs_musc=1 and ed_collgrad=1 then edbs_collmusc=1; else edbs_collmusc=0;

	/* Time to application: onset to filing (only for those who are allowed) */
	if ddpb_yy=9999  or ddpb_yy<1900 then ddpb_yy=.;
	if ddpb_mm=99 then ddpb_mm=.;
	if ddpb_dd=99 then ddpb_dd=.;
	if ddpb_mm=88 then ddpb_mm=.;
	if ddpb_dd=88 then ddpb_dd=.;
	ddpb_sas=mdy(ddpb_mm,ddpb_dd,ddpb_yy);
	n_daysapp=fld_sas-ddpb_sas;
	if n_daysapp<0 then n_daysapp=.;
	if n_daysapp>=0 & n_daysapp<=30 then n_daysapp_0mo1=1; else n_daysapp_0mo1=0;
	if n_daysapp>30 & n_daysapp<=60 then n_daysapp_1mo2=1; else n_daysapp_1mo2=0;
	if n_daysapp>60 & n_daysapp<=120 then n_daysapp_2mo4=1; else n_daysapp_2mo4=0;
	if n_daysapp>120 & n_daysapp<=180 then n_daysapp_4mo6=1; else n_daysapp_4mo6=0;
	if n_daysapp>180 & n_daysapp<=240 then n_daysapp_6mo8=1; else n_daysapp_6mo8=0;
	if n_daysapp>240 & n_daysapp<=300 then n_daysapp_8mo10=1; else n_daysapp_8mo10=0;
	if n_daysapp>300 & n_daysapp<=360 then n_daysapp_10mo12=1; else n_daysapp_10mo12=0;
	if n_daysapp>360 then n_daysapp_12mo=1; else n_daysapp_12mo=0;

	if n_daysapp=. then do;
		n_daysapp_0mo1=.;
		n_daysapp_1mo2=.;
		n_daysapp_2mo4=.;
		n_daysapp_4mo6=.;
		n_daysapp_6mo8=.;
		n_daysapp_8mo10=.;
		n_daysapp_10mo12=.;
		n_daysapp_12mo=.;
	end;

	/* Processing delay: filing to state receipt */
	if strdate_yy=9999 then strdate_yy=.;
	if strdate_mm=99 then strdate_mm=.;
	if strdate_dd=99 then strdate_dd=.;
	strdate_sas=mdy(strdate_mm, strdate_dd, strdate_yy);
	n_daysproc=strdate_sas-fld_sas;

	/* DDS decision time */
	if dodec_mm=2 & dodec_dd=29 then dodec_dd=28;
	if dodec_mm=2 & dodec_dd=30 then dodec_dd=28;
	if dodec_mm=2 & dodec_dd=31 then dodec_dd=28;
	if dodec_mm=4 & dodec_dd=31 then dodec_dd=30;
	if dodec_mm=6 & dodec_dd=31 then dodec_dd=30;
	if dodec_mm=9 & dodec_dd=31 then dodec_dd=30;
	if dodec_mm=11 & dodec_dd=31 then dodec_dd=30;
	dodec_sas=mdy(dodec_mm, dodec_dd, dodec_yy);
	n_ddsproc=dodec_sas-strdate_sas;

	/* Drop observations with missing or impossible filing date (<1% of cases) */
	if (fld_yy=. | fld_mm=. | fld_yy>&year.) then delete;

	/* Create quarters */
	if fld_mm>=1 & fld_mm<=3 then fld_qtr=1;
		else if fld_mm>=4 & fld_mm<=6 then fld_qtr=2;
		else if fld_mm>=7 & fld_mm<=9 then fld_qtr=3;
		else if fld_mm>=10 & fld_mm<=12 then fld_qtr=4;

run;

* COLLAPSE 831 TO SSN AND MERGE BACK IN TO GET EVER ALLOWED AT DDS LEVEL ;
proc means noprint data=data.tab_f831_cy&year. nway;
	by ssn;
	var allow_dds;
	output out=collapse_ssn_&year.
	MAX(allow_dds )=
		allow_dds ;
run;

data data.tab_f831_cy&year.;
	merge 
		data.tab_f831_cy&year. (drop=allow_dds )
		collapse_ssn_&year. (keep=ssn allow_dds );
	by ssn;
run;

%mend new;

%new(1989);
%new(1990);
%new(1991);
%new(1992);
%new(1993);
%new(1994);
%new(1995);
%new(1996);
%new(1997);
%new(1998);
%new(1999);
%new(2000);
%new(2001);
%new(2002);
%new(2003);
%new(2004);
%new(2005);
%new(2006);
%new(2007);
%new(2008);
%new(2009);
%new(2010);
%new(2011);
%new(2012);
%new(2013);
%new(2014);
%new(2015);
%new(2016);

run; quit;
