capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause on
# delimit;

/* 
Create Appendix Figure A.16
Input: 
	areacode_FN_forreg (from AEJ_PREP_AREACODE)
*/

use "`data'\areacode_FN_forreg.dta", clear;

/* ******************* */
/* **** DATA PREP **** */
/* ******************* */

gen moyear=ym(year, month);
gen emoyear=moyear-csetdate if csetdate!=.;
tab emoyear, m;

forval i=-2(1)26 {;
	gen byte emoyear_`=`i'+2'=(emoyear==`i' & treat==1);
};

count;
summ emoyear_*;

gen byte post=(emoyear>0);

gen temp=call_count if moyear==ym(2014, 1);
egen weight=max(call_count), by(areacode);


/* ********************* */
/* **** REGRESSIONS **** */
/* ********************* */

keep if emoyear<=6;

xi: statsby _b _se, saving("`data'\statsby\areacode_eventstudy.dta", replace):
	areg call_count
		emoyear_0 emoyear_1 emoyear_3-emoyear_8
		i.moyear 
	, absorb(areacode) vce(cluster areacode);
	
	
/* *********************** */
/* **** CREATE FIGURE **** */
/* *********************** */

use "`data'\statsby\areacode_eventstudy.dta", clear;

keep _b_emo* _se_emo*; 
gen _b_emoyear_2=0;
gen _se_emoyear_2=0;
gen id=1;
reshape long _b_emoyear_ _se_emoyear_, i(id) j(emoyear);
rename _b_emoyear_ b;
rename _se_emoyear_ se;

gen hi95=b+1.96*se;
gen lo95=b-1.96*se;

replace emoyear=emoyear-2;

twoway 	
	rarea hi95 lo95 emoyear, lcolor(white) lwidth(vvthin) color(orange) fin(30) ||
	connected b emoyear, lcolor(orange) mcolor(orange) msymbol(orange) 			
	title("Calls to 800 number", size(medsmall))
	xtitle("Month relative to closing", size(medsmall))
	ytitle("Reduced form estimate", size(medsmall))  ysc(r(-6000 6000)) ylab(-6000(3000)6000)
	yline(0, lcolor(gray))
	xline(0, lpattern(dash) lcolor(gray))
	legend(off)
	graphregion(color(white))
	bgcolor(white)
	ylabel(,nogrid)
	;
graph save "`output'\\figure16.gph", replace;


