capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Merge 831 data into main dataset
Input: 
	zip_for831_FNqtrnbr_append (from AEJ_PREP_831_2QTRNBR)
	collapse_zipappall_qtr (from SAS program AEJ_PREP_831_3COLLAPSE)
	collapse_zipappdiadult_qtr (from SAS program AEJ_PREP_831_3COLLAPSE)
	collapse_zipappssiadult_qtr (from SAS program AEJ_PREP_831_3COLLAPSE)
	collapse_zipappssikid_qtr (from SAS program AEJ_PREP_831_3COLLAPSE)
	collapse_zipfinall_qtr (from SAS program AEJ_PREP_831_3COLLAPSE)
	collapse_zipfindiadult_qtr (from SAS program AEJ_PREP_831_3COLLAPSE)
	collapse_zipfinssiadult_qtr (from SAS program AEJ_PREP_831_3COLLAPSE)
	collapse_zipfinssikid_qtr (from SAS program AEJ_PREP_831_3COLLAPSE)
*/

use "`data'\zip_for831_FNqtrnbr_append.dta", clear;

local pre "14";
local post "8";

local list_a_all "all_a_ctnum all_a_ctsevlow all_a_ctsevmed all_a_ctsevhigh all_a_ctsevvh all_a_ctbsmental all_a_ctbsmusc all_a_ctbsphys all_a_ctedhsdrop all_a_ctedhsgrad all_a_ctedcollgrad all_a_ctpearn0 all_a_ctpearn5 all_a_ctpearn15 all_a_ctpearn25 all_a_daysproc all_numprocgt40" ; 
local list_a_diadult "diadult_a_ctnum diadult_a_ctsevlow diadult_a_ctsevmed diadult_a_ctsevhigh diadult_a_ctsevvh diadult_a_daysproc diadult_a_ctage18to34 diadult_a_ctage35to49 diadult_a_ctage50plus diadult_a_ctage55to61 diadult_a_ctage62plus diadult_a_ctbsmental diadult_a_ctbsmusc diadult_a_ctbsphys diadult_a_ctedhsdrop diadult_a_ctedhsgrad diadult_a_ctedcollgrad diadult_a_online diadult_a_allowinit diadult_a_age diadult_a_bsmental diadult_a_bsmusc diadult_a_bsphys diadult_a_ed diadult_a_sevlow diadult_a_sevmed diadult_a_sevhigh diadult_a_sevvh" ;
local list_a_ssiadult "ssiadult_a_ctnum ssiadult_a_ctsevlow ssiadult_a_ctsevmed ssiadult_a_ctsevhigh ssiadult_a_ctsevvh ssiadult_a_daysproc ssiadult_a_ctage18to34 ssiadult_a_ctage35to49 ssiadult_a_ctage50plus ssiadult_a_ctbsmental ssiadult_a_ctbsphys ssiadult_a_ctbsmusc ssiadult_a_ctedhsdrop ssiadult_a_ctedhsgrad ssiadult_a_ctedcollgrad ssiadult_a_allowinit ssiadult_a_age ssiadult_a_bsmental ssiadult_a_bsmusc ssiadult_a_bsphys ssiadult_a_ed ssiadult_a_sevlow ssiadult_a_sevmed ssiadult_a_sevhigh ssiadult_a_sevvh" ;
local list_a_ssikid "ssikid_a_ctnum ssikid_a_ctsevlow ssikid_a_ctsevmed ssikid_a_ctsevhigh ssikid_a_ctsevvh ssikid_a_daysproc ssikid_a_ctage0to9 ssikid_a_ctage10to17 ssikid_a_ctbsmental ssikid_a_ctbsphys ssikid_a_allowinit ssikid_a_age ssikid_a_bsmental ssikid_a_bsphys ssikid_a_sevlow ssikid_a_sevmed ssikid_a_sevhigh ssikid_a_sevvh" ;

local list_r_all "all_r_ctnum all_r_ctsevlow all_r_ctsevmed all_r_ctsevhigh all_r_ctsevvh all_r_ctbsmental all_r_ctbsmusc all_r_ctbsphys all_r_ctedhsdrop all_r_ctedhsgrad all_r_ctedcollgrad all_r_ctpearn0 all_r_ctpearn5 all_r_ctpearn15 all_r_ctpearn25 all_r_ctage18to34 all_r_ctage35to49 all_r_ctage50plus all_r_age all_r_bsmental all_r_bsphys all_r_bsmusc all_r_ed all_r_sevlow all_r_sevmed all_r_sevhigh all_r_sevvh" ;
local list_r_diadult "diadult_r_ctnum diadult_r_ctsevlow diadult_r_ctsevmed diadult_r_ctsevhigh diadult_r_ctsevvh";
local list_r_ssiadult "ssiadult_r_ctnum ssiadult_r_ctsevlow ssiadult_r_ctsevmed ssiadult_r_ctsevhigh ssiadult_r_ctsevvh";
local list_r_ssikid "ssikid_r_ctnum ssikid_r_ctsevlow ssikid_r_ctsevmed ssikid_r_ctsevhigh ssikid_r_ctsevvh";


/* *********************************************** */
/* **** MERGE IN 831 DATA FOR VARIOUS GROUPS **** */
/* *********************************************** */

/* Merge in 831 application data */
foreach stub in all diadult ssiadult ssikid {;
	merge m:1 zip year quarter using "`data'\collapse_zipapp`stub'_qtr.dta", 
		keepusing(`list_a_`stub'');
	drop if _merge==2;
	gen byte from_831`stub'_ayes=(_merge==3);
	gen byte from_831`stub'_ano=(_merge==1);
	drop _merge;
};

/* Merge in 831 final allowance data */
foreach stub in all diadult ssiadult ssikid {;
	merge m:1 zip year quarter using "`data'\collapse_zipfin`stub'_qtr.dta", 
		keepusing(`list_r_`stub'');
	drop if _merge==2;
	gen byte from_831`stub'_ryes=(_merge==3);
	gen byte from_831`stub'_rno=(_merge==1);
	drop _merge;
};

/* Merge in wait time data */
merge m:1 office1 year quarter using "`data'\waittime_formerge_qtr.dta";
drop if _merge==2;
gen byte from_wait=(_merge==3);
drop _merge;
tab from_wait, m;

/* For ZIP-quarter combinations that don't match from 831, there were no applications */
foreach stub in all diadult ssiadult ssikid {;
	foreach var of varlist `stub'_a_ct* `stub'_r_ct* {;
		replace `var'=0 if from_831`stub'_ayes==0;
		replace `var'=0 if from_831`stub'_ryes==0;
	};
	tab from_831`stub'_ano, m; 
	tab from_831`stub'_rno, m;
};

/* ************************ */
/* **** DEFINE SAMPLES **** */
/* ************************ */

preserve;
keep if treat;
keep if eqtryear<0;

foreach stub in all diadult ssiadult ssikid {;
	egen byzip`stub'_nomatch=total(from_831`stub'_ano), by(zip);
	egen byzip`stub'_count=count(from_831`stub'_ano), by(zip);
	gen byzip`stub'_propno=byzip`stub'_nomatch/byzip`stub'_count;
	egen byzip`stub'_maxapp=max(`stub'_a_ctnum), by(zip);
	egen byzip`stub'_meanapp=mean(`stub'_a_ctnum), by(zip);
};

collapse byzip*, by(zip);

foreach stub in all diadult ssiadult ssikid {;
	tab byzip`stub'_nomatch, m;
};

foreach stub in all diadult ssiadult ssikid {;
	summ byzip`stub'_propno, det;
};

/* Max number of applications, by ZIP */
foreach stub in all diadult ssiadult ssikid {;
	tab byzip`stub'_maxapp, m;
	tab byzip`stub'_maxapp if byzip`stub'_nomatch>0 & byzip`stub'_nomatch!=., m;
	summ byzip`stub'_maxapp;
	summ byzip`stub'_maxapp if byzip`stub'_nomatch>0 & byzip`stub'_nomatch!=.;
};

/* Mean number of applications, by ZIP */
foreach stub in all diadult ssiadult ssikid {;
	summ byzip`stub'_meanapp;
	summ byzip`stub'_meanapp if byzip`stub'_nomatch>0 & byzip`stub'_nomatch!=.;
};

/* Define samples for each group */
gen byte sample_all=(byzipall_meanapp>3 & byzipall_meanapp!=.);
gen byte sample_diadult=(byzipdiadult_meanapp>3 & byzipdiadult_meanapp!=.);
gen byte sample_ssiadult=(byzipssiadult_meanapp>3 & byzipssiadult_meanapp!=.);
gen byte sample_ssikid=(byzipssikid_meanapp>2 & byzipssikid_meanapp!=.);

tempfile dropzip ;
save `dropzip' ;
restore;

merge m:1 zip using `dropzip', keepusing(sample*);
drop _merge;

foreach var of varlist sample* {;
	tab `var', m;
};

save "`data'\zip_for831_FNqtrnbr_forreg.dta", replace;
