capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Regressions for Figure 5 LHS
Input:
	zip_for831_eventqtr_forreg (from AEJ_PREP_831_3ESTUDYQTR)
*/ 

local pre "12";

/* **************************************** */
/* **** EVENT STUDY (NO CONTROL GROUP) **** */
/* **************************************** */

	use "`data'\zip_for831_eventqtr_forreg.dta", clear;

	/* Event year dummies */
	tab eqtryear, m;
	keep if eqtryear>=-`pre' & eqtryear<=8;
	tab eqtryear, m;
	forval eqtryear=-`pre'(1)8 {;
		gen byte eqtryear_`=`eqtryear'+`pre''=(eqtryear==`eqtryear');
	};

	summ eqtryear_*;

	/* Create weights */
	foreach stub in all diadult ssiadult ssikid {;
		gen temp_a_`stub'=`stub'_a_ctnum if eqtryear<0 & eqtryear>=-4;
		egen weight_a_`stub'=mean(temp_a_`stub'), by(cset zip);
		gen temp_r_`stub'=`stub'_r_ctnum if eqtryear<0 & eqtryear>=-4;
		egen weight_r_`stub'=mean(temp_r_`stub'), by(cset zip);
		drop temp_*;
	};

	/* Convert to log applications variable */
	foreach stub in all diadult ssiadult ssikid {;
		gen `stub'_a_lvlnum=`stub'_a_ctnum;
		gen `stub'_r_lvlnum=`stub'_r_ctnum;
		summ `stub'_a_* `stub'_r_*;
		foreach var of varlist `stub'_a_ct* `stub'_r_ct* {;
			replace `var' = 1 if `var'<=0;
			replace `var' = log(`var');
		};
		summ `stub'_a_ct* `stub'_r_ct*;
	};
	
	/* StateXyear fixed effects */
	if "8"=="8" { ;
		drop if year==2015 & (quarter==3 | quarter==4);
	} ;
	tab statecode, m;
	tab year, m;
	egen stateXyear=group(statecode year);
	tab stateXyear, m;
	gen unique=_n;
	egen temp=count(unique), by(stateXyear);
	tab temp, m;
	summ temp;
	pctile pct=temp, n(100);
	local p90=pct[90];
	replace stateXyear=9999 if temp<`p90' ;
	tab stateXyear, m;
	drop pct temp;

	
	/* Year by year regressions */
	
		foreach stub in all diadult ssiadult ssikid { ;
		
			foreach type in a r {;
			
				foreach var of varlist `list_`type'_`stub'' {;
					xi: statsby _b _se, saving("`data'\statsby\eventreg_qtr_`date'_`var'wt.dta", replace):
						areg `var'
							eqtryear_0-eqtryear_`=`pre'-3' eqtryear_`=`pre'-1'-eqtryear_`=8+`pre''
							i.stateXyear i.quarter 
							if sample_`stub'==1
							[aweight=weight_`type'_`stub']
						, absorb(zip) vce(cluster cset);
				};
				
				foreach var of varlist `stub'_`type'_lvlnum {;
					xi: statsby _b _se, saving("`data'\statsby\eventreg_qtr_`date'_`var'wt.dta", replace):
						areg `var'
							eqtryear_0-eqtryear_`=`pre'-3' eqtryear_`=`pre'-1'-eqtryear_`=8+`pre''
							i.stateXyear i.quarter 
							if sample_`stub'==1
							/* no weights */
						, absorb(zip) vce(cluster cset);
				}; 
				
			}; /* end type */
			
		}; /* end stub */
		
	
	/* Pre-post regressions and point estimates */

	local var_wout "post qtrzero" ;
	local var_with "post qtrzero t" ;
	
	/* Pre/post dummies */
	gen byte pre=(eqtryear<0);
	gen byte post=(eqtryear>0);
	gen byte qtrzero=(eqtryear==0);

	/* Event time trend */
	summ eqtryear;
	local min = r(min);
	gen t = eqtryear - `min' ;
	tab t, m;

	/* Starter */
	xi: areg all_a_ctnum
			post 
			if sample_all==1
		, absorb(zip) vce(cluster cset);
	outreg2 using "`output'\eventreg_qtr_`date'_wout.xls", replace;
	outreg2 using "`output'\eventreg_qtr_`date'_with.xls", replace;

	
		foreach time in wout with {;
		
			foreach stub in all diadult ssiadult ssikid { ;
			
				foreach type in a r {;
				
					foreach var of varlist `list_`type'_`stub'' {;
						xi: areg `var' 
								`var_`time'' 
								i.stateXyear i.quarter  
								if sample_all==1
								[aweight=weight_`type'_`stub']
							, absorb(zip) vce(cluster cset);
						outreg2 using "`output'\eventreg_qtr_`date'_`time'.xls", append;
					};
					
					foreach var of varlist `stub'_`type'_lvlnum {;
						xi: areg `var' 
								`var_`time''  
								i.stateXyear i.quarter  
								if sample_all==1
								/* no weights */
							, absorb(zip) vce(cluster cset);
						outreg2 using "`output'\eventreg_qtr_`date'_`time'.xls", append;
					};
					
				}; /*end type */
				
			}; /* end stub */
			
		}; /* end time */
		
