capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause off
# delimit;


local output "";
local log "";
local data "";

/* 
Regressions for Figures A.14
Input:
	zip_for831_FNqtr_forreg_post`post'.dta (from AEJ_PREP_831_3QTR_ALTWINDOW)
*/


foreach post in 4 6 8 10 12 {;

use "`data'\zip_for831_FNqtr_forreg_post`post'.dta", clear;

local pre "20";
scalar define scpre=20;
scalar define scpost=`post';

/* ****************************** */
/* **** PREP FOR REGRESSIONS **** */
/* ****************************** */

/* Event year dummies */
keep if eqtryear>=-`=scpre' & eqtryear<=`=scpost' ;
tab eqtryear, m;

forval eqtryear=-`=scpre'(1)`=scpost' {;
	gen byte eqtryear_`=`eqtryear'+`=scpre''=(eqtryear==`eqtryear');
};

forval eqtryear=-`=scpre'(1)`=scpost' {;
	gen trtXeqtryear_`=`eqtryear'+`=scpre''=treat*eqtryear_`=`eqtryear'+`=scpre'';
};

summ eqtryear_*;
drop eqtryear_*;
summ trtXeqtryear_*;

/* Create weights */
foreach stub in waitno waitap wait {;
	gen temp_`stub'=`stub'_count if eqtryear<0 & eqtryear>=-4;
	egen weight_`stub'=mean(temp_`stub'), by(cset zip);
	drop temp_*;
};

foreach stub in all diadult ssiadult ssikid {;
	gen temp_a_`stub'=`stub'_a_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_a_`stub'=mean(temp_a_`stub'), by(cset zip);
	gen temp_r_`stub'=`stub'_r_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_r_`stub'=mean(temp_r_`stub'), by(cset zip);
	drop temp_*;
};

/* Log applications */
foreach stub in all diadult ssiadult ssikid {;
	gen `stub'_a_lvlnum=`stub'_a_ctnum;
	gen `stub'_r_lvlnum=`stub'_r_ctnum;
	summ `stub'_a_ct* `stub'_r_ct*;
	foreach var of varlist `stub'_a_ct* `stub'_r_ct* {;
		replace `var' = 1 if `var'==0;
		replace `var' = log(`var');
	};
	summ `stub'_a_ct* `stub'_r_ct*;
};

/* Heterogeneity by distance */
summ distance1, det;
gen gp_dist=1 if distance1<10;
replace gp_dist=2 if distance1>=10 & distance1<30;
replace gp_dist=3 if distance1>=30 & distance1!=.;

/* Log population */
gen log_cty_pop=log(cty_pop);

/* StateXyear fixed effects */
drop if year==2015 & (quarter==3 | quarter==4);
tab statecode, m;
tab year, m;
egen stateXyear=group(statecode year);
tab stateXyear, m;
gen unique=_n;
egen temp=count(unique), by(stateXyear);
tab temp, m;
summ temp;
pctile pct=temp, n(100);
local p10=pct[10];
replace stateXyear=9999 if temp<`p10' ;
tab stateXyear, m;
drop pct temp;


/* ********************************** */
/* **** YEAR-BY-YEAR REGRESSIONS **** */
/* ********************************** */

foreach gp in a r {;
	{;
	xi: statsby _b _se, saving("`data'\statsby\FNreg_qtr_post`post'_ctnumwt.dta", replace):
	
		areg ctnum
			trtXeqtryear_0-trtXeqtryear_`=`pre'-3' trtXeqtryear_`=`pre'-1'-trtXeqtryear_`=`pre'+`post'' 
			treat i.eqtryear i.stateXyear i.quarter 
			if sample_all==1
			[aweight=weight_`gp'_all]
		, absorb(zip) vce(cluster closing);
	};
	};

};
