capture log close
clear all
set maxvar 10000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Create one data set of all main estimates
Input:
	FN_qtr_`date'_`cov'wt (from AEJ_PREP_831_4QTR)
	FN_qtrnbr_`date'_`cov'wt (from AEJ_PREP_831_4QTRNBR)
	FN_qtr_`date'_`cov'wt_robust (from AEJ_PREP_831_4QTR)
*/

local list_a_all "all_a_ctnum all_a_ctonline all_a_ctonlineno all_a_ctage18to34 all_a_ctage35to49 all_a_ctage50plus all_a_ctbsmental all_a_ctbsmusc all_a_ctbsphys all_a_ctedhsdrop all_a_ctedhsgrad all_a_ctedcollgrad all_a_ctsevlow all_a_ctsevmed all_a_ctsevhigh all_a_ctsevvh all_a_ctsevlownoapp all_a_ctsevlowapp";
local list_a_diadult "diadult_a_ctnum" ;
local list_a_ssiadult "ssiadult_a_ctnum" ;
local list_a_ssikid "ssikid_a_ctnum" ;

local list_a_all_earn "all_a_ctpearn0 all_a_ctpearn5 all_a_ctpearn15 all_a_ctpearn25 all_a_pearn" ;

local list_r_all "all_r_ctnum all_r_ctage18to34 all_r_ctage35to49 all_r_ctage50plus all_r_ctbsmental all_r_ctbsmusc all_r_ctbsphys all_r_ctedhsdrop all_r_ctedhsgrad all_r_ctedcollgrad all_r_ctsevmed all_r_ctsevhigh all_r_ctsevvh" ;
local list_r_diadult "diadult_r_ctnum" ;
local list_r_ssiadult "ssiadult_r_ctnum" ;
local list_r_ssikid "ssikid_r_ctnum" ;

local list_r_all_earn "all_r_ctpearn0 all_r_ctpearn5 all_r_ctpearn15 all_r_ctpearn25 all_r_pearn";

local list_nbra_all "all_a_ctnum all_a_daysproc" ; 
local list_nbra_diadult "diadult_a_ctnum" ;
local list_nbra_ssiadult "ssiadult_a_ctnum" ;
local list_nbra_ssikid "ssikid_a_ctnum" ;

local list_nbrr_all "all_r_ctnum" ;
local list_nbrr_diadult "diadult_r_ctnum";
local list_nbrr_ssiadult "ssiadult_r_ctnum";
local list_nbrr_ssikid "ssikid_r_ctnum";


/* ****************************************** */
/* **** CREATE ONE DATA SET OF ESTIMATES **** */
/* ****************************************** */

foreach stub in all diadult ssiadult ssikid {;
	foreach cov in 
		`stub'_a_lvlnum `list_a_`stub'' `list_a_`stub'_earn'
		`stub'_r_lvlnum `list_r_`stub'' `list_r_`stub'_earn' 
		{;

	use "`data'\statsby\FNreg_qtr_`date'_`cov'wt.dta", clear;
	
	/* Reshape data */
	keep _b_trtX* _se_trtX*; 
	gen _b_trtXeqtryear_10=0;
	gen _se_trtXeqtryear_10=0;
	gen id=1;
	reshape long _b_trtXeqtryear_ _se_trtXeqtryear_, i(id) j(eqtryear);
	rename _b_trtXeqtryear_ b_`cov';
	rename _se_trtXeqtryear_ se_`cov';
	
	gen hi95_`cov'=b+1.96*se;
	gen lo95_`cov'=b-1.96*se;
	drop id;
	replace eqtryear=eqtryear-12;
	
	save "`data'\statsby\clean_FNreg_qtr_`date'_`cov'wt.dta", replace;
};
};

foreach stub in all diadult ssiadult ssikid {;
	foreach cov in 
		`stub'_a_lvlnum `list_nbra_`stub'' 
		`stub'_r_lvlnum `list_nbrr_`stub'' 
		waitno_avg {;

	use "`data'\statsby\FNreg_qtrnbr_`date'_`cov'wt.dta", clear;
	
	/* Reshape data */
	keep _b_trtX* _se_trtX*; 
	gen _b_trtXeqtryear_10=0;
	gen _se_trtXeqtryear_10=0;
	gen id=1;
	reshape long _b_trtXeqtryear_ _se_trtXeqtryear_, i(id) j(eqtryear);
	rename _b_trtXeqtryear_ nbr_b_`cov';
	rename _se_trtXeqtryear_ nbr_se_`cov';
	
	gen nbr_hi95_`cov'=nbr_b+1.96*nbr_se;
	gen nbr_lo95_`cov'=nbr_b-1.96*nbr_se;
	drop id;
	replace eqtryear=eqtryear-12;
	
	save "`data'\statsby\clean_FNreg_qtrnbr_`cov'wt.dta", replace;
};
};

foreach cov in waitno_avg all_a_daysproc all_a_ddsproc ssacard_o_pcap_avg ssacard_r_pcap_avg {;

	use "`data'\statsby\FNreg_qtr_`date'_`cov'wt.dta", clear;
	
	/* Reshape data */
	keep _b_trtX* _se_trtX*; 
	gen _b_trtXeqtryear_10=0;
	gen _se_trtXeqtryear_10=0;
	gen id=1;
	reshape long _b_trtXeqtryear_ _se_trtXeqtryear_, i(id) j(eqtryear);
	rename _b_trtXeqtryear_ b_`cov';
	rename _se_trtXeqtryear_ se_`cov';
	
	gen hi95_`cov'=b+1.96*se;
	gen lo95_`cov'=b-1.96*se;
	drop id;
	replace eqtryear=eqtryear-12;
	
	save "`data'\statsby\clean_FNreg_qtr_`date'_`cov'wt.dta", replace;
};

foreach stub in all {;
	foreach cov in 
		`stub'_a_ctnum 
		`stub'_r_ctnum 
		{;

	use "`data'\statsby\FNreg_qtr_`date'_`cov'wt_robust.dta", clear;
	
	/* Reshape data */
	keep _b_trtX* _se_trtX*; 
	gen _b_trtXeqtryear_10=0;
	gen _se_trtXeqtryear_10=0;
	gen id=1;
	reshape long _b_trtXeqtryear_ _se_trtXeqtryear_, i(id) j(eqtryear);
	rename _b_trtXeqtryear_ b_`cov'_macro;
	rename _se_trtXeqtryear_ se_`cov'_macro;
	
	gen hi95_`cov'_macro=b+1.96*se;
	gen lo95_`cov'_macro=b-1.96*se;
	drop id;
	replace eqtryear=eqtryear-12;
	
	save "`data'\statsby\clean_FNreg_qtr_`date'_`cov'wt_macro.dta", replace;
};
};

foreach cov in cty_pop cty_lforce cty_urate cty_pinc cty_wageqtr cty_wagewk cty_employcew cty_employlau cty_unemploylau log_cty_pop {;

	use "`data'\statsby\FNreg_qtr_`date'_`cov'wt.dta", clear;
	
	/* Reshape data */
	keep _b_trtX* _se_trtX*; 
	gen _b_trtXeqtryear_10=0;
	gen _se_trtXeqtryear_10=0;
	gen id=1;
	reshape long _b_trtXeqtryear_ _se_trtXeqtryear_, i(id) j(eqtryear);
	rename _b_trtXeqtryear_ b_`cov';
	rename _se_trtXeqtryear_ se_`cov';
	
	gen hi95_`cov'=b+1.96*se;
	gen lo95_`cov'=b-1.96*se;
	drop id;
	replace eqtryear=eqtryear-12;
	
	save "`data'\statsby\clean_FNreg_qtr_`date'_`cov'wt.dta", replace;
};

/* Merge data sets and save */
use "`data'\statsby\clean_FNreg_qtr_`date'_all_a_ctnumwt.dta", clear;
keep eqtryear;

foreach stub in all diadult ssiadult ssikid {;
	foreach cov in 
		`stub'_a_lvlnum `list_a_`stub'' `list_a_`stub'_earn' 
		`stub'_r_lvlnum `list_r_`stub'' `list_r_`stub'_earn'  
		{;
	merge 1:1 eqtryear using "`data'\statsby\clean_FNreg_qtr_`date'_`cov'wt.dta";
	drop _merge;
	};
};

foreach stub in all {;
	foreach cov in 
		`stub'_a_ctnum `stub'_r_ctnum  
		{;
	merge 1:1 eqtryear using "`data'\statsby\clean_FNreg_qtr_`date'_`cov'wt_macro.dta";
	drop _merge;
	};
};

foreach stub in all diadult ssiadult ssikid {;
	foreach cov in 
		`stub'_a_lvlnum `list_nbra_`stub'' 
		`stub'_r_lvlnum `list_nbrr_`stub'' 
		waitno_avg 
		{;
	merge 1:1 eqtryear using "`data'\statsby\clean_FNreg_qtrnbr_`cov'wt.dta";
	drop _merge;
	};
};

foreach cov in 
		waitno_avg all_a_daysproc all_a_ddsproc ssacard_o_pcap_avg ssacard_r_pcap_avg
	{;
	merge 1:1 eqtryear using "`data'\statsby\clean_FNreg_qtr_`date'_`cov'wt.dta";
	drop _merge;
};


foreach cov in 
		cty_pop cty_lforce cty_urate cty_pinc cty_wageqtr cty_wagewk cty_employcew cty_employlau cty_unemploylau log_cty_pop 
	{;
	merge 1:1 eqtryear using "`data'\statsby\clean_FNreg_qtr_`date'_`cov'wt.dta";
	drop _merge;
};

save "`data'\statsby\merged_FNreg_qtr_`date'.dta", replace;
