capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause on
# delimit;

local output "";
local log "";
local data "";
local ssacards "";

/* 
Prep Social Security card data
Input: 
	ssacards_forstata (provided by Office of Earnings, Enumeration, and Adminsitrative Systems, 
				located in folder ../offices/data/ssacards)
	fo_Xwalk (created from SSA data, located in folder ../offices/data/zip)
*/

use "`ssacards'\ssacards_forstata.dta", clear;
rename office_num ofccode;
gen off_str_num=length(ofccode);
replace ofccode="0" + ofccode if off_str_num==2;
replace ofccode="00" + ofccode if off_str_num==1;
drop off_str_num;

/* Merge in new office numbers */
merge m:1 ofccode using "`data'\fo_Xwalk.dta";
keep if _merge==3;
drop _merge;

/* Create separate variables for original and replacement */
egen id=group(office_number year month);
drop if num=="|";
destring num, replace;
reshape wide num, i(id) j(type) string;
rename numORIGINAL ssacard_orig;
rename numREPLACEMENT ssacard_repl;
drop id;

save "`data'\ssacards_formerge_mo.dta", replace;

/* Collapse to quarter level */
gen quarter=1 if month>=1 & month<=3;
replace quarter=2 if month>=4 & month<=6;
replace quarter=3 if month>=7 & month<=9;
replace quarter=4 if month>=10 & month<=12;
collapse (sum) ssacard_orig ssacard_repl, by(office_number year quarter);
summ ssa*;
rename office_number office1;
describe office1;

save "`data'\ssacards_formerge_qtr.dta", replace;
