capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Run regressions for Table 2
Input: 
	zip_for831_FNqtr_forreg (from AEJ_831QTR_PREP3)
*/

use "`data'\zip_for831_FNqtr_forreg.dta", clear;

local pre "12";
local post "8";
scalar define scpre=12;
scalar define scpost=8;

local list_a_all "all_a_ctnum all_a_ctsevlow all_a_ctsevmed all_a_ctsevhigh all_a_ctsevvh all_a_ctbsmental all_a_ctbsmusc all_a_ctbsphys all_a_ctedhsdrop all_a_ctedhsgrad all_a_ctedcollgrad all_a_ctenglish all_a_ctenglishno all_a_ctage18to34 all_a_ctage35to49 all_a_ctage50plus all_a_ctonline all_a_ctonlineno all_a_ctemail all_a_ctemailno all_a_ctlawyer all_a_ctlawyerno all_a_ctsevlownoapp all_a_ctsevlowapp all_a_sevlow all_a_sevmed all_a_sevhigh all_a_sevvh all_a_bsmental all_a_bsmusc all_a_bsphys all_a_ed all_a_english all_a_age all_a_online all_a_email all_a_lawyer all_a_ctxdroplow all_a_ctxdropmed all_a_ctxdrophigh all_a_ctxdropvh all_a_ctxhslow all_a_ctxhsmed all_a_ctxhshigh all_a_ctxhsvh all_a_ctxcolllow all_a_ctxcollmed all_a_ctxcollhigh all_a_ctxcollvh all_a_ctxdropment all_a_ctxdropmusc all_a_ctxdropphys all_a_ctxhsment all_a_ctxhsmusc all_a_ctxhsphys all_a_ctxcollment all_a_ctxcollmusc all_a_ctxcollphys all_a_ctxmentlow all_a_ctxmentmed all_a_ctxmenthigh all_a_ctxmentvh all_a_ctxphyslow all_a_ctxphysmed all_a_ctxphyshigh all_a_ctxphysvh all_a_ctxmusclow all_a_ctxmuscmed all_a_ctxmuschigh all_a_ctxmuscvh all_a_ctonlhsdrop all_a_ctonlhsgrad all_a_ctonlcollgrad all_a_ctonnohsdrop all_a_ctonnohsgrad all_a_ctonnocollgrad"; 
local list_a_diadult "diadult_a_ctnum diadult_a_ctsevlow diadult_a_ctsevmed diadult_a_ctsevhigh diadult_a_ctsevvh diadult_a_ctbsmental diadult_a_ctbsmusc diadult_a_ctbsphys diadult_a_ctedhsdrop diadult_a_ctedhsgrad diadult_a_ctedcollgrad diadult_a_ctage18to34 diadult_a_ctage35to49 diadult_a_ctage50plus"; 
local list_a_ssiadult "ssiadult_a_ctnum ssiadult_a_ctsevlow ssiadult_a_ctsevmed ssiadult_a_ctsevhigh ssiadult_a_ctbsmental ssiadult_a_ctbsmusc ssiadult_a_ctbsphys ssiadult_a_ctsevvh ssiadult_a_ctedhsdrop ssiadult_a_ctedhsgrad ssiadult_a_ctedcollgrad ssiadult_a_ctage18to34 ssiadult_a_ctage35to49 ssiadult_a_ctage50plus"; 
local list_a_ssikid "ssikid_a_ctnum ssikid_a_ctsevlow ssikid_a_ctsevmed ssikid_a_ctsevhigh ssikid_a_ctsevvh ssikid_a_ctbsmental ssikid_a_ctbsphys ssikid_a_ctage0to9 ssikid_a_ctage10to17"; 

local list_a_all_earn "all_a_ctpearn0 all_a_ctpearn5 all_a_ctpearn15 all_a_ctpearn25 all_a_pearn"; 
local list_a_diadult_earn "diadult_a_ctpearn0 diadult_a_ctpearn5 diadult_a_ctpearn15 diadult_a_ctpearn25"; 
local list_a_ssiadult_earn "ssiadult_a_ctpearn0 ssiadult_a_ctpearn5 ssiadult_a_ctpearn15 ssiadult_a_ctpearn25"; 

/* ****************************** */
/* **** PREP FOR REGRESSIONS **** */
/* ****************************** */

keep if eqtryear>=-`=scpre' & eqtryear<=`=scpost' ;
tab eqtryear, m;

gen byte pre=(eqtryear<0);
gen byte post=(eqtryear>0);
gen byte qtrzero=(eqtryear==0);

gen trtXpost=treat*post;
gen trtXzero=treat*qtrzero;

/* Create weights */
foreach stub in waitno waitap wait {;
	gen temp_`stub'=`stub'_count if eqtryear<0 & eqtryear>=-4;
	egen weight_`stub'=mean(temp_`stub'), by(cset zip);
	drop temp_*;
};

foreach stub in all diadult ssiadult ssikid {;
	gen temp_a_`stub'=`stub'_a_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_a_`stub'=mean(temp_a_`stub'), by(cset zip);
	gen temp_r_`stub'=`stub'_r_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_r_`stub'=mean(temp_r_`stub'), by(cset zip);
	drop temp_*;
};

/* Convert to log applications variable */
foreach stub in all diadult ssiadult ssikid {;
	summ `stub'_a_ct* `stub'_r_ct*;
	foreach var of varlist `stub'_a_ct* `stub'_r_ct* {;
		replace `var' = 1 if `var'==0;
		replace `var' = log(`var');
	};
	summ `stub'_a_ct* `stub'_r_ct*;
};

/* State X year fixed effects */
drop if year==2015 & (quarter==3 | quarter==4);
tab statecode, m;
tab year, m;
egen stateXyear=group(statecode year);
tab stateXyear, m;
gen unique=_n;
egen temp=count(unique), by(stateXyear);
tab temp, m;
summ temp;
pctile pct=temp, n(100);
local p10=pct[10];
replace stateXyear=9999 if temp<`p10' ;
tab stateXyear, m;
drop pct temp;


/* ********************************************* */
/* **** PRE-POST REGRESSIONS FOR APPLICANTS **** */
/* ********************************************* */

foreach stub in all diadult ssiadult ssikid {;
	xi: areg `stub'_a_ctnum
			trtXpost trtXzero treat i.eqtryear  
			if sample_`stub'==1
		, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\qtr_table2_`stub'.xls", replace;
};

foreach stub in all diadult ssiadult ssikid {;
	foreach var of varlist 
		`list_a_`stub'' {;
		xi: areg `var' 
				trtXpost trtXzero treat
				i.eqtryear i.stateXyear i.quarter  
				if sample_`stub'==1
				[aweight=weight_a_`stub']
			, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\qtr_table2_`stub'.xls", append;
	};
};

foreach stub in all diadult ssiadult  {;
	foreach var of varlist 
		`list_a_`stub'_earn' {;
		xi: areg `var' 
				trtXpost trtXzero treat
				i.eqtryear i.stateXyear i.quarter  
				if sample_`stub'==1
				[aweight=weight_a_`stub']
			, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\qtr_table2_`stub'.xls", append;
	};
};
