capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Run regressions for Table 4
Input: 
	zip_for831_FNqtr_forreg (from AEJ_831QTR_PREP3)
	zip_for831_FNqtrnbr_forreg (from AEJ_831QTRNBR_PREP3)
*/

local pre "12";
local post "8";
scalar define scpre=12;
scalar define scpost=8;

/* *********************** */
/* **** CLOSINGS ZIPS **** */
/* *********************** */

use "`data'\zip_for831_FNqtr_forreg.dta", clear;

keep if eqtryear>=-`=scpre' & eqtryear<=`=scpost' ;
tab eqtryear, m;

gen byte pre=(eqtryear<0);
gen byte post=(eqtryear>0);
gen byte qtrzero=(eqtryear==0);

gen trtXpost=treat*post;
gen trtXzero=treat*qtrzero;

/* Create weights */
foreach stub in waitno waitap wait {;
	gen temp_`stub'=`stub'_count if eqtryear<0 & eqtryear>=-4;
	egen weight_`stub'=mean(temp_`stub'), by(cset zip);
	drop temp_*;
};

foreach stub in all diadult ssiadult ssikid {;
	gen temp_a_`stub'=`stub'_a_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_a_`stub'=mean(temp_a_`stub'), by(cset zip);
	gen temp_r_`stub'=`stub'_r_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_r_`stub'=mean(temp_r_`stub'), by(cset zip);
	drop temp_*;
};

/* Convert to log applications variable */
foreach stub in all diadult ssiadult ssikid {;
	summ `stub'_a_ct* `stub'_r_ct*;
	foreach var of varlist `stub'_a_ct* `stub'_r_ct* {;
		replace `var' = 1 if `var'==0;
		replace `var' = log(`var');
	};
	summ `stub'_a_ct* `stub'_r_ct*;
};

/* State X year fixed effects */
drop if year==2015 & (quarter==3 | quarter==4);
tab statecode, m;
tab year, m;
egen stateXyear=group(statecode year);
tab stateXyear, m;
gen unique=_n;
egen temp=count(unique), by(stateXyear);
tab temp, m;
summ temp;
pctile pct=temp, n(100);
local p10=pct[10];
replace stateXyear=9999 if temp<`p10' ;
tab stateXyear, m;
drop pct temp;

	xi: areg all_a_ctnum
			trtXpost trtXzero treat i.eqtryear  
			if sample_all==1
		, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\table4.xls", replace;

xi: areg all_r_ctnum
			trtXpost trtXzero treat i.eqtryear  
			if sample_all==1
		, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\table4.xls", append

	xi: areg waitno_avg 
			trtXpost trtXzero treat
			i.eqtryear i.stateXyear i.quarter  
			if qtryear>=yq(2004,4) & sample_all==1
			[aweight=weight_a_all]
		, absorb(zip) vce(cluster closing);	
	outreg2 using "`output'\table4.xls", append;

foreach stub in  all_a_daysproc all_numprocgt40 {;
	xi: areg `stub' 
			trtXpost trtXzero treat
			i.eqtryear i.stateXyear i.quarter  
			if sample_all==1
			[aweight=weight_a_all]
		, absorb(zip) vce(cluster closing);	
	outreg2 using "`output'\table4.xls", append;
};

foreach stub in time_driving1 dist_driving1 time_transit1 {;
	xi: areg `stub' 
			trtXpost trtXzero treat
			i.eqtryear i.stateXyear i.quarter  
			if sample_all==1
			[aweight=weight_a_all]
		, absorb(zip) vce(cluster closing);	
	outreg2 using "`output'\table4.xls", append;
};


/* ************************** */
/* **** NEIGHBORING ZIPS **** */
/* ************************** */

use "`data'\zip_for831_FNqtrnbr_forreg.dta", clear;

keep if eqtryear>=-`=scpre' & eqtryear<=`=scpost' ;
tab eqtryear, m;

gen byte pre=(eqtryear<0);
gen byte post=(eqtryear>0);
gen byte qtrzero=(eqtryear==0);

gen trtXpost=treat*post;
gen trtXzero=treat*qtrzero;

/* Create weights */
foreach stub in waitno waitap wait {;
	gen temp_`stub'=`stub'_count if eqtryear<0 & eqtryear>=-4;
	egen weight_`stub'=mean(temp_`stub'), by(cset zip);
	drop temp_*;
};

foreach stub in all diadult ssiadult ssikid {;
	gen temp_a_`stub'=`stub'_a_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_a_`stub'=mean(temp_a_`stub'), by(cset zip);
	gen temp_r_`stub'=`stub'_r_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_r_`stub'=mean(temp_r_`stub'), by(cset zip);
	drop temp_*;
};

/* Convert to log applications variable */
foreach stub in all diadult ssiadult ssikid {;
	summ `stub'_a_ct* `stub'_r_ct*;
	foreach var of varlist `stub'_a_ct* `stub'_r_ct* {;
		replace `var' = 1 if `var'==0;
		replace `var' = log(`var');
	};
	summ `stub'_a_ct* `stub'_r_ct*;
};

/* State X year fixed effects */
drop if year==2015 & (quarter==3 | quarter==4);
tab statecode, m;
tab year, m;
egen stateXyear=group(statecode year);
tab stateXyear, m;
gen unique=_n;
egen temp=count(unique), by(stateXyear);
tab temp, m;
summ temp;
pctile pct=temp, n(100);
local p10=pct[10];
replace stateXyear=9999 if temp<`p10' ;
tab stateXyear, m;
drop pct temp;

/* Regressions */
		xi: areg all_a_ctnum
				trtXpost trtXzero treat
				i.eqtryear i.stateXyear i.quarter
				if sample_`stub'==1
				[aweight=weight_a_all]
			, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\table4_qtrnbr.xls", replace

		xi: areg all_r_ctnum 
				trtXpost trtXzero treat
				i.eqtryear i.stateXyear i.quarter
				if sample_all==1
				[aweight=weight_r_all]
			, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\table4_qtrnbr.xls", append;

xi: areg waitno_avg 
		trtXpost trtXzero treat
		i.eqtryear i.stateXyear i.quarter
		if qtryear>=yq(2004,4) & sample_all==1
		[aweight=weight_waitno]
	, absorb(zip) vce(cluster closing);	
outreg2 using "`output'\table4_qtrnbr.xls", append;

foreach out in daysproc numprocgt40 {;
	xi: areg all_a_`out'
			trtXpost trtXzero treat
			i.eqtryear i.stateXyear i.quarter
			if sample_all==1
			[aweight=weight_a_all]
		, absorb(zip) vce(cluster closing);	
	outreg2 using "`output'\table4_qtrnbr.xls", append;
};
