capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Run regressions for Appendix Table A.18
Input: 
	zip_for831_FNqtr_forreg (from AEJ_831QTR_PREP3)
*/

use "`data'\zip_for831_FNqtr_forreg.dta", clear;

local pre "12";
local post "8";
scalar define scpre=12;
scalar define scpost=8;

/* ****************************** */
/* **** PREP FOR REGRESSIONS **** */
/* ****************************** */

keep if eqtryear>=-`=scpre' & eqtryear<=`=scpost' ;
tab eqtryear, m;

gen byte pre=(eqtryear<0);
gen byte post=(eqtryear>0);
gen byte qtrzero=(eqtryear==0);

gen trtXpost=treat*post;
gen trtXzero=treat*qtrzero;

/* Create weights */
foreach stub in waitno waitap wait {;
	gen temp_`stub'=`stub'_count if eqtryear<0 & eqtryear>=-4;
	egen weight_`stub'=mean(temp_`stub'), by(cset zip);
	drop temp_*;
};

foreach stub in all diadult ssiadult ssikid {;
	gen temp_a_`stub'=`stub'_a_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_a_`stub'=mean(temp_a_`stub'), by(cset zip);
	gen temp_r_`stub'=`stub'_r_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_r_`stub'=mean(temp_r_`stub'), by(cset zip);
	drop temp_*;
};

/* Convert to log applications variable */
foreach stub in all diadult ssiadult ssikid {;
	summ `stub'_a_ct* `stub'_r_ct*;
	foreach var of varlist `stub'_a_ct* `stub'_r_ct* {;
		replace `var' = 1 if `var'==0;
		replace `var' = log(`var');
	};
	summ `stub'_a_ct* `stub'_r_ct*;
};

/* State X year fixed effects */
drop if year==2015 & (quarter==3 | quarter==4);
tab statecode, m;
tab year, m;
egen stateXyear=group(statecode year);
tab stateXyear, m;
gen unique=_n;
egen temp=count(unique), by(stateXyear);
tab temp, m;
summ temp;
pctile pct=temp, n(100);
local p10=pct[10];
replace stateXyear=9999 if temp<`p10' ;
tab stateXyear, m;
drop pct temp;


/* ****************************** */
/* **** PRE-POST REGRESSIONS **** */
/* ****************************** */

	xi: areg all_a_ctonlhsdrop 
			trtXpost trtXzero treat
				i.eqtryear i.stateXyear i.quarter  
				if sample_`stub'==1
				[aweight=weight_a_`stub']
		, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\table18.xls", replace;

	foreach var of varlist 
		all_a_ctonlhsdrop all_a_ctonlhsgrad all_a_ctonlcollgrad all_a_ctonnohsdrop all_a_ctonnohsgrad all_a_ctonnocollgrad {;
		xi: areg `var' 
				trtXpost trtXzero treat
				i.eqtryear i.stateXyear i.quarter  
				if sample_`stub'==1
				[aweight=weight_a_`stub']
			, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\table18.xls", append;
	};